==> spacejunk-1.0.3.tar.gz: spacejunk-1.0.3/src/scorelist.cpp <==
/*
  Copyright (C) 2009 Facundo Domínguez 

  This file is part of Spacejunk.

  Spacejunk is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  Foobar is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "scorelist.h"
#include "parsercombinators.h"
#include <iostream>
#include <SDL.h>
#include <unistd.h>
#include <fstream>
#include <sstream>
#include <iterator>
#include <assert.h>

using namespace std;

ScoreList::ScoreList() {
    if (access("scores.hi",F_OK)) return;

    ifstream f("scores.hi");
    if (f.fail()) {
        SDL_SetError("Error reading score list: Could not open file scores.hi");
        exit(1);
    }
    f>>*this;
    if (f.fail()) {
        cout<<"On file \"scores.hi\": "<<SDL_GetError()<<endl;
        exit(1);
    };
};

ScoreList::~ScoreList() {
    ofstream f("scores.hi");
    if (f.fail()) {
        cerr<<"Error writing score list: Could not open file scores.hi\n";
    }
    f<<*this;
    if (f.fail()) {
        cout<<"Writting file \"scores.hi\": "<<SDL_GetError()<<endl;
    };
}

bool ScoreList::inside(int points) {
    return scores.upper_bound(points)!=scores.end();
};

int ScoreList::size() const {
    return scores.size();
};
int ScoreList::position(iterator i) {
    return distance(scores.begin(),i);
};
void ScoreList::erase(iterator i) {
    scores.erase(i);
};
void ScoreList::setName(const std::string & name,iterator i) {
    i->second=name;
};
void ScoreList::erase_last() {
    assert(!scores.empty());
    scores.erase(--scores.end());
};

ScoreList::iterator ScoreList::setScore(const string & name,int points) {
    return scores.insert(make_pair(points,name));
};

string ScoreList::getNames() const {
    ostringstream temp;
    for (Map::const_iterator i=scores.begin();i!=scores.end();i++)
        temp<<i->second<<"\n";
    return temp.str();
};
string ScoreList::getPoints() const {
    ostringstream temp;
    for (Map::const_iterator i=scores.begin();i!=scores.end();i++)
        temp<<i->first<<"\n";
    return temp.str();
};


ostream & operator << (ostream & o,const ScoreList & s) {
    STDStreamPrinter sp(o);
    OStreamUTF8Encoder sc(&sp);
    for (multimap<int,string>::const_iterator i=s.scores.begin();i!=s.scores.end();i++)
        sc<<'"'<<stows(i->second)<<"\" "<<i->first<<'\n';
    return o;
};

istream & operator >> (istream & i,ScoreList & s) {
    StreamTokenizer t(i);
    basic_string<wchar_t> wname;
    Lexer p=&t;
    PARSEbegin(Lexer,p);
    MANYbegin
    int points;
    LATTTEXT(&wname);
    LINT(&points);
    s.setScore(wstos(wname),points);
    MANYend
    PARSEend;

    if (p.error()) {
        SDL_SetError((string("Reading ScoreList: "+p.errorMessage()).c_str()));
        i.setstate(ios::failbit);
    } else if (i.eof()) i.clear(ios::eofbit);

    return i;
};

==> spacejunk-1.0.5.tar.gz: spacejunk-1.0.5/src/scorelist.cpp <==
/*
  Copyright (C) 2009 Facundo Domínguez 

  This file is part of Spacejunk.

  Spacejunk is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  Foobar is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "scorelist.h"
#include "resourcemanager.h"
#include "parsercombinators.h"
#include <iostream>
#include <SDL.h>
#include <unistd.h>
#include <fstream>
#include <sstream>
#include <iterator>
#include <assert.h>

using namespace std;

ScoreList::ScoreList() {
    if (access((GetResourcePath()+"scores.hi").c_str(),F_OK)) return;

    ifstream f((GetResourcePath()+"scores.hi").c_str());
    if (f.fail()) {
        SDL_SetError("Error reading score list: Could not open file scores.hi");
        exit(1);
    }
    f>>*this;
    if (f.fail()) {
        cout<<"On file \""<<(GetResourcePath()+"scores.hi").c_str()<<"\": "<<SDL_GetError()<<endl;
        exit(1);
    };
};

ScoreList::~ScoreList() {
    ofstream f((GetResourcePath()+"scores.hi").c_str());
    if (f.fail()) {
        cerr<<"Error writing score list: Could not open file "<<(GetResourcePath()+"scores.hi").c_str()<<"\n";
    }
    f<<*this;
    if (f.fail()) {
        cout<<"Writting file \""<<(GetResourcePath()+"scores.hi").c_str()<<"\": "<<SDL_GetError()<<endl;
    };
}

bool ScoreList::inside(int points) {
    return scores.upper_bound(points)!=scores.end();
};

int ScoreList::size() const {
    return scores.size();
};
int ScoreList::position(iterator i) {
    return distance(scores.begin(),i);
};
void ScoreList::erase(iterator i) {
    scores.erase(i);
};
void ScoreList::setName(const std::string & name,iterator i) {
    i->second=name;
};
void ScoreList::erase_last() {
    assert(!scores.empty());
    scores.erase(--scores.end());
};

ScoreList::iterator ScoreList::setScore(const string & name,int points) {
    return scores.insert(make_pair(points,name));
};

string ScoreList::getNames() const {
    ostringstream temp;
    for (Map::const_iterator i=scores.begin();i!=scores.end();i++)
        temp<<i->second<<"\n";
    return temp.str();
};
string ScoreList::getPoints() const {
    ostringstream temp;
    for (Map::const_iterator i=scores.begin();i!=scores.end();i++)
        temp<<i->first<<"\n";
    return temp.str();
};


ostream & operator << (ostream & o,const ScoreList & s) {
    STDStreamPrinter sp(o);
    OStreamUTF8Encoder sc(&sp);
    for (multimap<int,string>::const_iterator i=s.scores.begin();i!=s.scores.end();i++)
        sc<<'"'<<stows(i->second)<<"\" "<<i->first<<'\n';
    return o;
};

istream & operator >> (istream & i,ScoreList & s) {
    StreamTokenizer t(i);
    basic_string<wchar_t> wname;
    Lexer p=&t;
    PARSEbegin(Lexer,p);
    MANYbegin
    int points;
    LATTTEXT(&wname);
    LINT(&points);
    s.setScore(wstos(wname),points);
    MANYend
    PARSEend;

    if (p.error()) {
        SDL_SetError((string("Reading ScoreList: "+p.errorMessage()).c_str()));
        i.setstate(ios::failbit);
    } else if (i.eof()) i.clear(ios::eofbit);

    return i;
};
